from typing import List
from fastapi import APIRouter, Depends, HTTPException, status
from sqlalchemy.orm import Session
from app.db import get_db
from app.models import Register
from app.schemas import RegisterCreate, RegisterResponse

router = APIRouter()

@router.post("/new", response_model=RegisterResponse, status_code=status.HTTP_201_CREATED)
async def create_register(register_data: RegisterCreate, db: Session = Depends(get_db)):
    """
    Create a new register
    """
    register = Register(**register_data.dict())
    db.add(register)
    db.commit()
    db.refresh(register)
    return register

@router.get("/new", response_model=List[RegisterResponse])
async def get_registers(db: Session = Depends(get_db)):
    """
    Get all registers
    """
    registers = db.query(Register).all()
    return registers